Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(121)

Unified Diff: content/browser/frame_host/render_frame_host_impl.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/render_frame_host_impl.cc
diff --git a/content/browser/frame_host/render_frame_host_impl.cc b/content/browser/frame_host/render_frame_host_impl.cc
index 5e28794978dd025a4a351bd026740ac4dce01e22..20d8919cd7837a2bd7f327dc5f4afb3a5048fcef 100644
--- a/content/browser/frame_host/render_frame_host_impl.cc
+++ b/content/browser/frame_host/render_frame_host_impl.cc
@@ -2188,7 +2188,7 @@ void RenderFrameHostImpl::OnUpdateToUniqueOrigin(
"frame_tree_node", frame_tree_node_->frame_tree_node_id());
url::Origin origin;
- DCHECK(origin.unique());
+ DCHECK(origin.opaque());
frame_tree_node()->SetCurrentOrigin(origin,
is_potentially_trustworthy_unique_origin);
}
@@ -3033,16 +3033,16 @@ bool RenderFrameHostImpl::CanCommitOrigin(
return true;
}
// It is safe to commit into a unique origin, regardless of the URL, as it is
// restricted from accessing other origins.
- if (origin.unique())
+ if (origin.opaque())
return true;
// Standard URLs must match the reported origin.
if (url.IsStandard() && !origin.IsSamePhysicalOriginWith(url::Origin(url)))
return false;
// A non-unique origin must be a valid URL, which allows us to safely do a
// conversion to GURL.
GURL origin_url = origin.GetPhysicalOrigin().GetURL();
« no previous file with comments | « content/browser/frame_host/navigator_impl_unittest.cc ('k') | content/browser/frame_host/render_frame_host_manager.cc » ('j') | no next file with comments »
@@ -3033,16 +3033,16 @@ bool RenderFrameHostImpl::CanCommitOrigin(
return true;
}
- // It is safe to commit into a unique origin, regardless of the URL, as it is
+ // It is safe to commit into a opaque origin, regardless of the URL, as it is
// restricted from accessing other origins.
@@ -3033,16 +3033,16 @@ bool RenderFrameHostImpl::CanCommitOrigin(
if (url.IsStandard() && !origin.IsSamePhysicalOriginWith(url::Origin(url)))
return false;
- // A non-unique origin must be a valid URL, which allows us to safely do a
+ // A non-opaque origin must be a valid URL, which allows us to safely do a
// conversion to GURL.
GURL origin_url = origin.GetPhysicalOrigin().GetURL();

Powered by Google App Engine
This is Rietveld 408576698